useDynLib(distr, .registration = TRUE, .fixes = "C_")
import("methods")
import("stats")
importFrom("grDevices", "dev.list", "dev.new", "xy.coords", "dev.off")
importFrom("graphics", "plot", "abline", "layout", "legend", "lines", "mtext", "par", "points", "title")
importFrom("MASS", "ginv")
importFrom("utils", "str")
importFrom("sfsmisc", "D1ss")
import("startupmsg")

export("Beta", "Binom", "Cauchy", "Chisq",  
       "Dirac","Exp", "DExp", "Fd", "Gammad", 
       "Geom", "Hyper", "Lnorm", "Logis", 
       "Nbinom", "Norm", "Pois", "RtoDPQ", 
       "RtoDPQ.d", "Td", "Unif", "Weibull", "Arcsine", 
       "distroptions", "getdistrOption", "simplifyr",
       "Lattice", "DiscreteDistribution",
       "EmpiricalDistribution",
       "LatticeDistribution", "EuclideanSpace", "Reals", 
       "Naturals", "standardMethods", 
       "distrARITH", "distrMASK", "getLabel", "devNew")
export("AbscontDistribution")
export("DistrList", "UnivarDistrList")
export("makeAbscontDistribution") 
exportClasses("rSpace", "EuclideanSpace", "Reals", 
              "Naturals")
exportClasses("Parameter")
exportClasses("OptionalParameter", "OptionalMatrix")
exportClasses("BetaParameter", "BinomParameter", 
              "CauchyParameter", "ChisqParameter",
              "DiracParameter", "ExpParameter", 
              "FParameter", "GammaParameter", 
              "HyperParameter",
              "LogisParameter", "LnormParameter",
              "NbinomParameter", "NormParameter", 
              "PoisParameter", "TParameter",
              "UnifParameter", "WeibullParameter", 
              "UniNormParameter")
exportClasses("Distribution")
exportClasses("UnivariateDistribution", "AbscontDistribution", 
              "DiscreteDistribution", "LatticeDistribution", 
              "AffLinAbscontDistribution", "AffLinDiscreteDistribution", 
              "AffLinLatticeDistribution", "AffLinDistribution", "Lattice",
              "Beta", "Binom", "Cauchy", "Chisq", "Dirac", 
              "DExp", "Exp", "Fd", "Gammad", "Geom", 
              "Hyper", "Logis", "Lnorm", "Nbinom", "Norm", 
              "Pois", "Td", "Unif", "Weibull", "Arcsine",
              "ExpOrGammaOrChisq")
exportClasses("UnivDistrListOrDistribution")
exportClasses("CompoundDistribution")
exportClasses("DistrList", 
              "UnivarDistrList")
exportClasses("OptionalNumeric", "PosSemDefSymmMatrix",
              "PosDefSymmMatrix",
              "Symmetry", "DistributionSymmetry",
              "NoSymmetry", "EllipticalSymmetry", "SphericalSymmetry",
              "DistrSymmList")
exportMethods("Max", "Max<-", "Min", "Min<-", "d", "df", 
              "df<-", "df1", "df1<-", "df2", 
              "df2<-", "dimension", "dimension<-", "name", 
              "name<-", "img", "k", "k<-", 
              "lambda", "lambda<-", "liesIn", "location", 
              "location<-", "m", "m<-", "mean", 
              "mean<-", "meanlog", "meanlog<-", "n", 
              "n<-", "ncp", "ncp<-", "p", "param", 
              "prob", "prob<-", "q", "r", "rate", "p.l", "q.r",
              "rate<-", "scale", "scale<-", "sd", "sd<-", 
              "sdlog", "sdlog<-", "shape", "shape<-", 
              "shape1", "shape1<-", "shape2", "shape2<-", 
              "size", "size<-", "support", "initialize", 
              "print", "plot", "+", "-", "/", "*", "coerce",
              "Math", "log", "log10", "gamma", "lgamma", "digamma", 
              "dim", "show", "convpow", "pivot", "sign",
              "lattice", "width", "Length", "pivot<-", 
              "width<-", "Length<-", "liesInSupport",
              "isOldVersion", "conv2NewVersion", "gaps",
              "gaps<-", "setgaps", "getLow", "getUp")
exportClasses("UnivarMixingDistribution",
              "UnivarLebDecDistribution",
              "AffLinUnivarLebDecDistribution",
              "AcDcLcDistribution")
exportMethods("mixCoeff", "mixCoeff<-", "mixDistr", "mixDistr<-",
              "discretePart", "discretePart<-", "acPart", "acPart<-",
              "discreteWeight", "discreteWeight<-", "acWeight", "acWeight<-",
              "p.discrete", "d.discrete", "q.discrete", "r.discrete",
              "p.ac", "d.ac", "q.ac", "r.ac", "p.r", "q.l")
exportMethods("decomposePM", "simplifyD", "showobj")
exportMethods("Truncate","Minimum","Maximum","Huberize")
exportMethods("solve", "sqrt")
exportMethods("type", "SymmCenter", "Symmetry", ".logExact", ".lowerExact")
export("UnivarMixingDistribution", "UnivarLebDecDistribution")
export("RtoDPQ.LC", "flat.LCD", "flat.mix")
exportMethods("abs","exp","^")
exportMethods("NumbOfSummandsDistr","SummandsDistr")
export("CompoundDistribution")
export("PosDefSymmMatrix","PosSemDefSymmMatrix")
export("NoSymmetry", "EllipticalSymmetry", "SphericalSymmetry",
       "DistrSymmList") 
export("qqbounds","igamma")
exportMethods("qqplot")
export(".isEqual",".isEqual01", ".inArgs", ".fillList", 
       ".presubs", ".makeLenAndOrder", ".DistrCollapse")
export("samplesize", "distribution", "samplesize<-")	   
