## borrowed from Andy Liaw's rfNews()


distrARITH <- function(library = NULL) 
{
    infoShow(pkg = "distr", filename = "ARITHMETICS", library = library)
}

distrMASK <- function(library = NULL) 
{
    infoShow(pkg = "distr", filename="MASKING", library = library)
}
