\name{img-methods}
\docType{methods}
\alias{img-methods}
\alias{img}
\alias{img,Distribution-method}
\title{ Methods for Function img in Package `distr'}
\description{img-methods}

\section{Methods}{\describe{

\item{img}{\code{signature(object  = "Distribution")}: returns the image space / domain of the distribution }
}}
\keyword{methods}
\keyword{distribution}
\concept{space}
\concept{range space of a distribution}
\concept{accessor function}
