\name{mean-methods}
\docType{methods}
\alias{mean-methods}
\alias{mean<--methods}
\alias{mean}
\alias{mean<-}
\alias{mean,NormParameter-method}
\alias{mean,Norm-method}
\alias{mean<-,NormParameter-method}
\alias{mean<-,Norm-method}
\title{ Methods for Function mean in Package `distr' }
\description{mean-methods}
\section{Methods}{\describe{
\item{mean}{\code{signature(object = "NormParameter")}: returns the slot mean of the parameter of the distribution }    
\item{mean<-}{\code{signature(object = "NormParameter")}: modifies the slot mean of the parameter of the distribution }
\item{mean}{\code{signature(object = "Norm")}: returns the slot mean of the parameter of the distribution }
\item{mean<-}{\code{signature(object = "Norm")}: modifies the slot mean of the parameter of the distribution }
}}
\keyword{methods}
\keyword{distribution}
\concept{parameter}
\concept{Normal distribution}
\concept{Gaussian distribution}
\concept{S4 parameter class}
\concept{location scale family}
\concept{location parameter}
\concept{accessor function}
\concept{replacement function}
