\name{NoSymmetry}
\alias{NoSymmetry}

\title{Generating function for NoSymmetry-class}
\description{Generates an object of class \code{"NoSymmetry"}.}
\usage{NoSymmetry()}
%\details{}
\value{Object of class \code{"NoSymmetry"}}
%\references{}
\author{Matthias Kohl \email{Matthias.Kohl@stamats.de}}
%\note{}
\seealso{\code{\link{NoSymmetry-class}}, \code{\link{DistributionSymmetry-class}}}
\examples{
NoSymmetry()

## The function is currently defined as
function(){ new("NoSymmetry") }
}
\concept{symmetry}
\keyword{distribution}
