\name{sdlog-methods}
\docType{methods}
\alias{sdlog-methods}
\alias{sdlog<--methods}
\alias{sdlog}
\alias{sdlog<-}
\alias{sdlog,LnormParameter-method}
\alias{sdlog,Lnorm-method}
\alias{sdlog<-,LnormParameter-method}
\alias{sdlog<-,Lnorm-method}
\title{ Methods for Function sdlog in Package `distr' }
\description{sdlog-methods}
\section{Methods}{\describe{

\item{sdlog}{\code{signature(object = "LnormParameter")}: returns the slot \code{sdlog} of the parameter of the distribution }
\item{sdlog<-}{\code{signature(object = "LnormParameter")}: modifies the slot \code{sdlog} of the parameter of the distribution }

\item{sdlog}{\code{signature(object = "Lnorm")}: returns the slot \code{sdlog} of the parameter of the distribution }
\item{sdlog<-}{\code{signature(object = "Lnorm")}: modifies the slot \code{sdlog} of the parameter of the distribution }
}}
\keyword{methods}
\keyword{distribution}
\concept{parameter}
\concept{Log-Normal distribution}
\concept{S4 parameter class}
\concept{accessor function}
\concept{replacement function}
