\name{OptionalParameter-class}
\docType{class}
\alias{OptionalParameter-class}
\alias{OptionalMatrix-class}

\title{Classes "OptionalParameter", "OptionalMatrix" }
\description{ auxiliary classes; may contain either a Parameter or NULL, resp.
a matrix or NULL cf. J. Chambers, "green book".}
\section{Objects from the Class}{"OptionalParameter" is a virtual Class: No objects may be created from it;
"OptionalMatrix" is a class generated by \code{setClassUnion()} so may contain NULL or any matrix}
\section{Methods}{
No methods defined with class "OptionalParameter" in the signature.
}
\author{
  Thomas Stabla \email{statho3@web.de},\cr 
  Florian Camphausen \email{fcampi@gmx.de},\cr
  Peter Ruckdeschel \email{peter.ruckdeschel@uni-oldenburg.de},\cr
  Matthias Kohl \email{Matthias.Kohl@stamats.de}
}
\seealso{\code{\link{Parameter-class}}, \code{\link{AbscontDistribution-class}}}
\keyword{methods}
\keyword{distribution}
\concept{parameter}
\concept{S4 parameter class}
\concept{class union}
\concept{virtual class}
