\name{m-methods}
\docType{methods}
\alias{m-methods}
\alias{m<--methods}
\alias{m}
\alias{m<-}
\alias{m,HyperParameter-method}
\alias{m,Hyper-method}
\alias{m<-,HyperParameter-method}
\alias{m<-,Hyper-method}
\title{ Methods for Function m in Package `distr' }
\description{m-methods}
\section{Methods}{\describe{
\item{m}{\code{signature(object = "HyperParameter")}: returns the slot m of the parameter of the distribution }
\item{m<-}{\code{signature(object = "HyperParameter")}: modifies the slot m of the parameter of the distribution }
\item{m}{\code{signature(object = "Hyper")}: returns the slot m of the parameter of the distribution }
\item{m<-}{\code{signature(object = "Hyper")}: modifies the slot m of the parameter of the distribution }
}}
\keyword{methods}
\keyword{distribution}
\concept{parameter}
\concept{Hypergeometric distribution}
\concept{S4 parameter class}
\concept{accessor function}
\concept{replacement function}
