\name{print-methods}
\docType{methods}
\alias{print-methods}
\alias{show-methods}
\alias{print,UnivariateDistribution-method}
\alias{show,UnivariateDistribution-method}
\alias{show,LatticeDistribution-method}
\alias{show,UnivarMixingDistribution-method}
\alias{show,UnivarLebDecDistribution-method}
\title{ Methods for Functions print/show in Package `distr' }
\description{print/show-methods}

\section{Methods}{\describe{

\item{print}{\code{signature(x = "UnivariateDistribution")}: returns the class of the object and its parameters }
\item{show}{\code{signature(x = "UnivariateDistribution")}: returns the class of the object and its parameters }

}}
\keyword{print}
\keyword{methods}
\keyword{distribution}
