\name{n-methods}
\docType{methods}
\alias{n-methods}
\alias{n<--methods}
\alias{n}
\alias{n<-}
\alias{n,HyperParameter-method}
\alias{n,Hyper-method}
\alias{n<-,HyperParameter-method}
\alias{n<-,Hyper-method}
\title{ Methods for Function n in Package `distr' }
\description{n-methods}

\section{Methods}{\describe{

\item{n}{\code{signature(object = "HyperParameter")}: returns the slot \code{n} of the parameter of the distribution }
\item{n<-}{\code{signature(object = "HyperParameter")}: modifies the slot \code{n} of the parameter of the distribution }

\item{n}{\code{signature(object = "Hyper")}: returns the slot \code{n} of the parameter of the distribution }
\item{n<-}{\code{signature(object = "Hyper")}: modifies the slot \code{n} of the parameter of the distribution }
}}
\keyword{methods}
\keyword{distribution}
\concept{parameter}
\concept{Hypergeometric distribution}
\concept{S4 parameter class}
\concept{accessor function}
\concept{replacement function}
