\name{dim-methods}
\docType{methods}
\alias{dim-methods}
\alias{dim}
\alias{dim,UnivariateDistribution-method}

\title{ Methods for Function dim in Package `distr' }
\description{dim-methods}
\section{Methods}{\describe{
    \item{dim}{\code{signature(object = "UnivariateDistribution")}: returns the dimension of the distribution }
}}
\seealso{
\code{\link{UnivariateDistribution-class}}
}
\keyword{methods}
\concept{dimension}
\concept{space}
\concept{accessor function}
