\name{support-methods}
\docType{methods}
\alias{support-methods}
\alias{support}
\alias{support,DiscreteDistribution-method}
\title{Methods for Function support in Package `distr'}
\description{support-methods}

\section{Methods}{\describe{

\item{support}{\code{signature(object =
    "DiscreteDistribution")}: returns the support}
}}
\keyword{distribution}
\keyword{methods}
\concept{discrete distribution}
\concept{support}
\concept{S4 distribution class}
\concept{accessor function}
