\name{size-methods}
\docType{methods}
\alias{size-methods}
\alias{size<--methods}
\alias{size}
\alias{size<-}
\alias{size,BinomParameter-method}
\alias{size,Binom-method}
\alias{size,NbinomParameter-method}
\alias{size,Nbinom-method}
\alias{size,Geom-method}
\alias{size<-,BinomParameter-method}
\alias{size<-,Binom-method}
\alias{size<-,NbinomParameter-method}
\alias{size<-,Nbinom-method}
\alias{size<-,Geom-method}
\title{ Methods for Function size in Package `distr' }
\description{size-methods}

\section{Methods}{\describe{

\item{size}{\code{signature(object  = "BinomParameter")}: returns the slot \code{size} of the parameter of the distribution }
\item{size<-}{\code{signature(object = "BinomParameter")}: modifies the slot \code{size} of the parameter of the distribution }

\item{size}{\code{signature(object = "Binom")}: returns the slot \code{size} of the parameter of the distribution }
\item{size<-}{\code{signature(object = "Binom")}: modifies the slot \code{size} of the parameter of the distribution }

\item{size}{\code{signature(object = "NbinomParameter")}: returns the slot \code{size} of the parameter of the distribution }
\item{size<-}{\code{signature(object = "NbinomParameter")}: modifies the slot \code{size} of the parameter of the distribution }

\item{size}{\code{signature(object = "Nbinom")}: returns the slot \code{size} of the parameter of the distribution }
\item{size<-}{\code{signature(object = "Nbinom")}: modifies the slot \code{size} of the parameter of the distribution }

\item{size}{\code{signature(object = "Geom")}: returns the slot \code{size} of the parameter of the distribution }

}}
\keyword{distribution}
\concept{parameter}
\concept{Binomial distribution}
\concept{Negative Binomial distribution}
\concept{Geometric distribution}
\concept{S4 parameter class}
\concept{accessor function}
\concept{replacement function}
