\name{width-methods}
\docType{methods}
\alias{width-methods}
\alias{width<--methods}
\alias{width}
\alias{width<-}
\alias{width,Lattice-method}
\alias{width<-,Lattice-method}
\alias{width,LatticeDistribution-method}
\alias{width<-,LatticeDistribution-method}
\title{ Methods for Function width in Package `distr' }
\description{width-methods}
\section{Methods}{\describe{
\item{width}{\code{signature(object = "Lattice")}: returns the slot width of the lattice }
\item{width<-}{\code{signature(object = "Lattice")}: modifies the slot width of the lattice }
\item{width}{\code{signature(object = "LatticeDistribution")}: returns the slot width of the lattice slot of the distribution}
\item{width<-}{\code{signature(object = "LatticeDistribution")}: modifies the slot width of the lattice slot of the distribution}
}}
\keyword{methods}
\keyword{distribution}
\concept{space}
\concept{S4 space class}
\concept{lattice}
\concept{affine linear lattice}
\concept{accessor function}
\concept{replacement function}
