\name{liesIn-methods}
\docType{methods}
\alias{liesIn-methods}
\alias{liesIn}
\alias{liesIn,EuclideanSpace,numeric-method}
\alias{liesIn,Naturals,numeric-method}
\title{ Methods for Function liesIn in Package `distr' }
\description{liesIn-methods}
\section{Methods}{\describe{
    \item{liesIn}{\code{signature(object = "EuclideanSpace", x =
	"numeric")}}:
    
    Does a particular vector lie in this space or not?
    \item{liesIn}{\code{signature(object = "Naturals", x =
	"numeric")}}:
    
    Does a particular vector only contain naturals?}
  }
\keyword{distribution}
\keyword{methods}
\concept{space}
\concept{S4 space class}
\concept{set}
