\name{ncp-methods}
\docType{methods}
\alias{ncp-methods}
\alias{ncp<--methods}
\alias{ncp}
\alias{ncp<-}
\alias{ncp,ChisqParameter-method}
\alias{ncp,Chisq-method}
\alias{ncp<-,ChisqParameter-method}
\alias{ncp<-,Chisq-method}
\alias{ncp,FParameter-method}
\alias{ncp,Fd-method}
\alias{ncp<-,FParameter-method}
\alias{ncp<-,Fd-method}
\alias{ncp,BetaParameter-method}
\alias{ncp,Beta-method}
\alias{ncp<-,BetaParameter-method}
\alias{ncp<-,Beta-method}
\alias{ncp,TParameter-method}
\alias{ncp,Td-method}
\alias{ncp<-,TParameter-method}
\alias{ncp<-,Td-method}
\title{ Methods for Function ncp in Package `distr' }
\description{ncp-methods}

\section{Methods}{\describe{

\item{ncp}{\code{signature(object = "BetaParameter")}: returns the slot \code{ncp} of the parameter of the distribution }
\item{ncp<-}{\code{signature(object = "BetaParameter")}: modifies the slot \code{ncp} of the parameter of the distribution }

\item{ncp}{\code{signature(object = "Beta")}: returns the slot \code{ncp} of the parameter of the distribution }
\item{ncp<-}{\code{signature(object = "Beta")}: modifies the slot \code{ncp} of the parameter of the distribution }

\item{ncp}{\code{signature(object = "ChisqParameter")}: returns the slot \code{ncp} of the parameter of the distribution }
\item{ncp<-}{\code{signature(object = "ChisqParameter")}: modifies the slot \code{ncp} of the parameter of the distribution }

\item{ncp}{\code{signature(object = "Chisq")}: returns the slot \code{ncp} of the parameter of the distribution }
\item{ncp<-}{\code{signature(object = "Chisq")}: modifies the slot \code{ncp} of the parameter of the distribution }

\item{ncp}{\code{signature(object = "FParameter")}: returns the slot \code{ncp} of the parameter of the distribution }
\item{ncp<-}{\code{signature(object = "FParameter")}: modifies the slot \code{ncp} of the parameter of the distribution }

\item{ncp}{\code{signature(object = "Fd")}: returns the slot \code{ncp} of the parameter of the distribution }
\item{ncp<-}{\code{signature(object = "Fd")}: modifies the slot \code{ncp} of the parameter of the distribution }

\item{ncp}{\code{signature(object = "TParameter")}: returns the slot \code{ncp} of the parameter of the distribution }
\item{ncp<-}{\code{signature(object = "TParameter")}: modifies the slot \code{ncp} of the parameter of the distribution }

\item{ncp}{\code{signature(object = "Td")}: returns the slot \code{ncp} of the parameter of the distribution }
\item{ncp<-}{\code{signature(object = "Td")}: modifies the slot \code{ncp} of the parameter of the distribution }

}}
\keyword{methods}
\keyword{distribution}
\concept{parameter}
\concept{Chi square distribution}
\concept{beta distribution}
\concept{T distribution}
\concept{F distribution}
\concept{non centrality parameter}
\concept{S4 parameter class}
\concept{accessor function}
\concept{replacement function}
