\name{df-methods}
\docType{methods}
\alias{df-methods}
\alias{df<--methods}
\alias{df}
\alias{df<-}
\alias{df,TParameter-method}
\alias{df,Td-method}
\alias{df,ChisqParameter-method}
\alias{df,Chisq-method}
\alias{df<-,TParameter-method}
\alias{df<-,Td-method}
\alias{df<-,ChisqParameter-method}
\alias{df<-,Chisq-method}
\title{ Methods for Function df in Package `distr' }
\description{df-methods}

\section{Methods}{\describe{

\item{df}{\code{signature(object = "TParameter")}: returns the slot \code{df} of the parameter of the distribution }
\item{df<-}{\code{signature(object = "TParameter")}: modifies the slot \code{df} of the parameter of the distribution }

\item{df}{\code{signature(object = "Td")}: returns the slot \code{df} of the parameter of the distribution }
\item{df<-}{\code{signature(object = "Td")}: modifies the slot \code{df} of the parameter of the distribution }

\item{df}{\code{signature(object = "ChisqParameter")}: returns the slot \code{df} of the parameter of the distribution }
\item{df<-}{\code{signature(object = "ChisqParameter")}: modifies the slot \code{df} of the parameter of the distribution }

\item{df}{\code{signature(object = "Chisq")}: returns the slot \code{df} of the parameter of the distribution }
\item{df<-}{\code{signature(object = "Chisq")}: modifies the slot \code{df} of the parameter of the distribution }
}}
\keyword{distribution}
\keyword{methods}
\concept{degree of freedom}
\concept{parameter}
\concept{T distribution}
\concept{Chi square distribution}
\concept{accessor function}
\concept{replacement function}
